package com.coomix.app.newbusiness.ui.route

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.support.constraint.ConstraintLayout
import android.support.v7.widget.DividerItemDecoration
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import com.coomix.app.car.GlobalParam
import com.coomix.app.car.R
import com.coomix.app.car.activity.MonitorParentFragment
import com.coomix.app.car.bean.Device
import com.coomix.app.car.bean.DeviceState
import com.coomix.app.newbusiness.data.BaseSubscriber
import com.coomix.app.newbusiness.data.DataEngine
import com.coomix.app.newbusiness.data.ExceptionHandle.ResponeThrowable
import com.coomix.app.newbusiness.data.RxUtils
import com.coomix.app.newbusiness.model.response.DevInfo
import com.coomix.app.newbusiness.model.response.RespRouteDevs
import com.coomix.app.newbusiness.model.response.RouteInfo
import com.coomix.app.newbusiness.ui.base.BaseActivityY
import com.coomix.app.newbusiness.ui.route.DevAdapter.DevHolder
import com.coomix.app.newbusiness.ui.route.DevAdapter.OnItemClickListener
import com.coomix.app.util.SettingDataManager
import kotlinx.android.synthetic.main.activity_route_car_list.carList
import kotlinx.android.synthetic.main.activity_route_car_list.toolbar

/**
 * File Description:
 *
 * @author felixqiu
 * @since 2019-12-10.
 */
class RouteCarListActivity : BaseActivityY() {
    lateinit var routeInfo: RouteInfo
    val devs = ArrayList<DevInfo>()
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_route_car_list)
        initIntent(intent)
        initViews()
        initData()
    }

    private fun initIntent(intent: Intent?) {
        if (intent == null) {
            finish()
        }
        val b = intent?.getBundleExtra(MonitorParentFragment.KEY_ROUTEINFO)
        routeInfo = b?.getSerializable(MonitorParentFragment.KEY_ROUTEINFO) as RouteInfo
    }

    private fun initData() {
        val token = GlobalParam.getInstance()._access_token
        val d = DataEngine.getCarTrackingApi()
            .getRouteDevs(
                routeInfo.lineno, 0, System.currentTimeMillis() / 1000, token,
                GlobalParam.getInstance().commonParas
            )
            .compose(RxUtils.businessTransformer())
            .compose(RxUtils.toMain())
            .subscribeWith(object : BaseSubscriber<RespRouteDevs>() {
                override fun onNext(t: RespRouteDevs?) {
                    processDevs(t?.data?.dev_info ?: mutableListOf())
                }

                override fun onHttpError(e: ResponeThrowable?) {
                    showToast(e?.errCodeMessage)
                }
            })
        subscribeRx(d)
    }

    private fun initViews() {
        toolbar.initActionbar(true, routeInfo.linename, 0, 0)
        carList.layoutManager = LinearLayoutManager(this)
        val ad = DevAdapter(this, devs)
        ad.onItemClickListener = object : OnItemClickListener {
            override fun onItemClick(position: Int) {
                gotoHistory(position)
            }
        }
        carList.adapter = ad
        carList.addItemDecoration(DividerItemDecoration(this, DividerItemDecoration.VERTICAL))
    }

    private fun processDevs(list: MutableList<DevInfo>) {
        if (list.size < 1) {
            return
        }
        devs.clear()
        devs.addAll(list)
        carList.adapter.notifyDataSetChanged()
    }

    private fun gotoHistory(position: Int) {
        val dev = Device()
        dev.imei = devs[position].imei
        dev.name = devs[position].dev_name
        dev.number = devs[position].plate
        dev.state = DeviceState()
        SettingDataManager.getInstance(this).goToHistoryActivity(this, dev, false)
    }
}

class DevAdapter(
    val activity: Context,
    var data: List<DevInfo>
) : RecyclerView.Adapter<DevHolder>() {
    var onItemClickListener: OnItemClickListener? = null
    override fun onCreateViewHolder(
        parent: ViewGroup?,
        viewType: Int
    ): DevHolder {
        val itemView = LayoutInflater.from(parent?.context).inflate(R.layout.item_route_dev_list, parent, false)
        return DevHolder(itemView)
    }

    override fun getItemCount(): Int = data.size

    override fun onBindViewHolder(
        holder: DevHolder?,
        position: Int
    ) {
        holder?.devName?.text = data[position].dev_name
        holder?.devNo?.text = data[position].plate
        holder?.root?.setOnClickListener() {
            onItemClickListener?.onItemClick(position)
        }
    }

    class DevHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        var devName = itemView.findViewById<TextView>(R.id.devName)
        var devNo = itemView.findViewById<TextView>(R.id.devNo)
        var root = itemView.findViewById<ConstraintLayout>(R.id.itemRoot)
    }

    interface OnItemClickListener {
        fun onItemClick(position: Int)
    }
}