package com.coomix.app.newbusiness.ui.route

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.support.constraint.ConstraintLayout
import android.support.v7.widget.DividerItemDecoration
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import com.coomix.app.car.GlobalParam
import com.coomix.app.car.R
import com.coomix.app.car.activity.MonitorParentFragment
import com.coomix.app.newbusiness.data.BaseSubscriber
import com.coomix.app.newbusiness.data.DataEngine
import com.coomix.app.newbusiness.data.ExceptionHandle.ResponeThrowable
import com.coomix.app.newbusiness.data.RxUtils
import com.coomix.app.newbusiness.model.response.RespRouteList
import com.coomix.app.newbusiness.model.response.RouteInfo
import com.coomix.app.newbusiness.ui.base.BaseActivityY
import com.coomix.app.newbusiness.ui.route.RouteAdapter.RouteHolder
import kotlinx.android.synthetic.main.activity_route_info.routeList
import kotlinx.android.synthetic.main.activity_route_info.toolbar
import java.util.ArrayList

class RouteInfoActivity : BaseActivityY() {

    var routes: MutableList<RouteInfo> = ArrayList()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_route_info)
        initViews()
        initData()
    }

    private fun initData() {
        val token = GlobalParam.getInstance()._access_token
        val d = DataEngine.getCarTrackingApi().getRouteList(token, GlobalParam.getInstance().commonParas)
            .compose(RxUtils.businessTransformer())
            .compose(RxUtils.toMain())
            .subscribeWith(object : BaseSubscriber<RespRouteList>() {
                override fun onNext(t: RespRouteList?) {
                    processData(t?.data?.linelist ?: mutableListOf())
                }

                override fun onHttpError(e: ResponeThrowable?) {
                    showToast(e?.errCodeMessage)
                }
            })
        subscribeRx(d)
    }

    private fun initViews() {
        toolbar.initActionbar(true, R.string.route_info, 0, 0)
        routeList.layoutManager = LinearLayoutManager(this)
        routeList.adapter = RouteAdapter(this, routes)
        routeList.addItemDecoration(DividerItemDecoration(this, DividerItemDecoration.VERTICAL))
    }

    fun testData() {
        for (i in 1..10) {
            routes.add(RouteInfo(222, "线路$i", "332"))
        }
    }

    fun processData(t: MutableList<RouteInfo>) {
        routes.clear()
        routes.addAll(t)
        routeList.adapter.notifyDataSetChanged()
    }

}

class RouteAdapter(
    val activity: Context,
    var data: List<RouteInfo>
) : RecyclerView.Adapter<RouteHolder>() {
    override fun onCreateViewHolder(
        parent: ViewGroup?,
        viewType: Int
    ): RouteHolder {
        val itemView = LayoutInflater.from(parent?.context).inflate(R.layout.item_route_list, parent, false)
        return RouteHolder(itemView)
    }

    override fun getItemCount(): Int = data.size

    override fun onBindViewHolder(
        holder: RouteHolder?,
        position: Int
    ) {
        holder?.lineName?.text = data[position].linename
        holder?.lineName?.setOnClickListener() {
            if (activity is RouteInfoActivity) {
                val b = Bundle()
                b.putSerializable(MonitorParentFragment.KEY_ROUTEINFO, data[position])
                activity.setResult(Activity.RESULT_OK, Intent().putExtra(MonitorParentFragment.KEY_ROUTEINFO, b))
                activity.finish()
            }
        }
        holder?.line?.setOnClickListener() {
            val b = Bundle()
            b.putSerializable(MonitorParentFragment.KEY_ROUTEINFO, data[position])
            val i = Intent(activity, RouteCarListActivity::class.java).putExtra(MonitorParentFragment.KEY_ROUTEINFO, b)
            activity.startActivity(i)
        }
    }

    class RouteHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        var lineName = itemView.findViewById<TextView>(R.id.lineName)
        var line = itemView.findViewById<ConstraintLayout>(R.id.line)
    }
}